## Tools: TL

```{eval-rst}
.. module:: scanpy.external.tl
.. currentmodule:: scanpy.external
```

### Embeddings

```{eval-rst}
.. autosummary::
   :toctree: generated/

   tl.phate
   tl.palantir
   tl.trimap
   tl.sam
```

### Clustering and trajectory inference

```{eval-rst}
.. autosummary::
   :toctree: generated/

   tl.phenograph
   tl.harmony_timeseries
   tl.wishbone
   tl.palantir
   tl.palantir_results
```

### Gene scores, Cell cycle

```{eval-rst}
.. autosummary::
   :toctree: generated/

   tl.sandbag
   tl.cyclone

```
